package com.temboo.Library.Amazon.Marketplace.Orders;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListOrdersWithSellerOrderId

Returns orders associated with a seller order id that you specify.
*/
public class ListOrdersWithSellerOrderId extends Choreography {

	/**
	Create a new instance of the ListOrdersWithSellerOrderId Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListOrdersWithSellerOrderId(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Orders/ListOrdersWithSellerOrderId"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListOrdersWithSellerOrderIdInputSet
	*/
	public ListOrdersWithSellerOrderIdInputSet newInputSet() {
		return new ListOrdersWithSellerOrderIdInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListOrdersWithSellerOrderIdResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListOrdersWithSellerOrderIdResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListOrdersWithSellerOrderId
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListOrdersWithSellerOrderIdInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}


		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}


		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}


		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}


		/** 
		Set the value of the CreatedAfter input for this Choreo. 

		@param String - (optional, date) A date used for selecting orders created after (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01). Defaults to today's date if not provided.
		*/
		public void set_CreatedAfter(String value) {
			this.setInput("CreatedAfter", value);
		}


		/** 
		Set the value of the CreatedBefore input for this Choreo. 

		@param String - (optional, date) A date used for selecting orders created before (or at) a specified time, in ISO 8601 date format (i.e. 2012-01-01).
		*/
		public void set_CreatedBefore(String value) {
			this.setInput("CreatedBefore", value);
		}


		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}


		/** 
		Set the value of the MWSAuthToken input for this Choreo. 

		@param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
		*/
		public void set_MWSAuthToken(String value) {
			this.setInput("MWSAuthToken", value);
		}


		/** 
		Set the value of the MaxResultsPerPage input for this Choreo. 

		@param Integer - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
		*/
		public void set_MaxResultsPerPage(Integer value) {
			this.setInput("MaxResultsPerPage", value);
		}

		/** 
		Set the value of the MaxResultsPerPage input for this Choreo as a String. 

		@param String - (optional, integer) A number that indicates the maximum number of orders that can be returned per page. Valid values are: 1-100.
		*/
		public void set_MaxResultsPerPage(String value) {
			this.setInput("MaxResultsPerPage", value);	
		}
		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the SellerOrderId input for this Choreo. 

		@param String - (required, string) An order identifier that is specified by the seller.
		*/
		public void set_SellerOrderId(String value) {
			this.setInput("SellerOrderId", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListOrdersWithSellerOrderId Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListOrdersWithSellerOrderIdResultSet extends ResultSet {
		public ListOrdersWithSellerOrderIdResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - Stores the response from Amazon.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
