package com.temboo.Library.Dropbox.Files;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
Move

Moves a file or folder to a different location in the user's Dropbox.
*/
public class Move extends Choreography {

	/**
	Create a new instance of the Move Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public Move(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dropbox/Files/Move"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return MoveInputSet
	*/
	public MoveInputSet newInputSet() {
		return new MoveInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public MoveResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new MoveResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the Move
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class MoveInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token for a specific Dropbox user.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the AllowSharedFolder input for this Choreo. 

		@param Boolean - (optional, boolean) If true, contents are copied into a shared folder, otherwise an error will be returned if the FromPath contains a shared folder. The default for this field is false.
		*/
		public void set_AllowSharedFolder(Boolean value) {
			this.setInput("AllowSharedFolder", value);
		}

		/** 
		Set the value of the AllowSharedFolder input for this Choreo as a String. 

		@param String - (optional, boolean) If true, contents are copied into a shared folder, otherwise an error will be returned if the FromPath contains a shared folder. The default for this field is false.
		*/
		public void set_AllowSharedFolder(String value) {
			this.setInput("AllowSharedFolder", value);	
		}
		/** 
		Set the value of the AutoRename input for this Choreo. 

		@param Boolean - (optional, boolean) If there's a conflict, have the Dropbox server try to autorename the file to avoid the conflict. The default for this field is false.
		*/
		public void set_AutoRename(Boolean value) {
			this.setInput("AutoRename", value);
		}

		/** 
		Set the value of the AutoRename input for this Choreo as a String. 

		@param String - (optional, boolean) If there's a conflict, have the Dropbox server try to autorename the file to avoid the conflict. The default for this field is false.
		*/
		public void set_AutoRename(String value) {
			this.setInput("AutoRename", value);	
		}
		/** 
		Set the value of the FromPath input for this Choreo. 

		@param String - (required, string) Path in the user's Dropbox to be copied or moved.
		*/
		public void set_FromPath(String value) {
			this.setInput("FromPath", value);
		}


		/** 
		Set the value of the ToPath input for this Choreo. 

		@param String - (required, string) Path in the user's Dropbox that is the destination.
		*/
		public void set_ToPath(String value) {
			this.setInput("ToPath", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the Move Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class MoveResultSet extends ResultSet {
		public MoveResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Dropbox.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
