package com.temboo.Library.Dropbox.Sharing;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RevokeSharedLink

Revokes a shared link.
*/
public class RevokeSharedLink extends Choreography {

	/**
	Create a new instance of the RevokeSharedLink Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RevokeSharedLink(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Dropbox/Sharing/RevokeSharedLink"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RevokeSharedLinkInputSet
	*/
	public RevokeSharedLinkInputSet newInputSet() {
		return new RevokeSharedLinkInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RevokeSharedLinkResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RevokeSharedLinkResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RevokeSharedLink
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RevokeSharedLinkInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token for a specific Dropbox user.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the URL input for this Choreo. 

		@param String - (required, string) The URL of the shared link.
		*/
		public void set_URL(String value) {
			this.setInput("URL", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RevokeSharedLink Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RevokeSharedLinkResultSet extends ResultSet {
		public RevokeSharedLinkResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Dropbox.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
