package com.temboo.Library.Facebook.Reading;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
FriendshipExists

Determines whether two people are friends on Facebook.
*/
public class FriendshipExists extends Choreography {

	/**
	Create a new instance of the FriendshipExists Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public FriendshipExists(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Reading/FriendshipExists"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return FriendshipExistsInputSet
	*/
	public FriendshipExistsInputSet newInputSet() {
		return new FriendshipExistsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public FriendshipExistsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new FriendshipExistsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the FriendshipExists
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class FriendshipExistsInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final OAuth step.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the ProfileID input for this Choreo. 

		@param String - (optional, string) The ID of the user whose friends list you want to check the UserID against. Defaults to "me" indicating the authenticated user.
		*/
		public void set_ProfileID(String value) {
			this.setInput("ProfileID", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID of the user to check against the acting user's list of friends.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the FriendshipExists Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class FriendshipExistsResultSet extends ResultSet {
		public FriendshipExistsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "IsFriend" output from this Choreo execution

		@return String - (boolean) Returns as true or false depending on whether or not the UserID specified corresponds to a friend of the acting user.
		*/
		public String get_IsFriend() {
			return this.getResultString("IsFriend");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
