package com.temboo.Library.Highrise;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreatePeople

Creates a new contact record in your Highrise CRM.
*/
public class CreatePeople extends Choreography {

	/**
	Create a new instance of the CreatePeople Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreatePeople(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Highrise/CreatePeople"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreatePeopleInputSet
	*/
	public CreatePeopleInputSet newInputSet() {
		return new CreatePeopleInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreatePeopleResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreatePeopleResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreatePeople
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreatePeopleInputSet extends InputSet {
		/** 
		Set the value of the AccountName input for this Choreo. 

		@param String - (required, string) A valid Highrise account name. This is the first part of the account's URL.
		*/
		public void set_AccountName(String value) {
			this.setInput("AccountName", value);
		}


		/** 
		Set the value of the Background input for this Choreo. 

		@param String - (optional, string) Corresponds to the background field in Highrise
		*/
		public void set_Background(String value) {
			this.setInput("Background", value);
		}


		/** 
		Set the value of the CompanyName input for this Choreo. 

		@param String - (optional, string) Corresponds to the company name field in Highrise.
		*/
		public void set_CompanyName(String value) {
			this.setInput("CompanyName", value);
		}


		/** 
		Set the value of the EmailAddress input for this Choreo. 

		@param String - (optional, string) Corresponds to the email address field in Highrise.
		*/
		public void set_EmailAddress(String value) {
			this.setInput("EmailAddress", value);
		}


		/** 
		Set the value of the FirstName input for this Choreo. 

		@param String - (required, string) Corresponds to the first name field in Highrise.
		*/
		public void set_FirstName(String value) {
			this.setInput("FirstName", value);
		}


		/** 
		Set the value of the HomePhone input for this Choreo. 

		@param String - (optional, string) Corresponds to the home phone field in Highrise.
		*/
		public void set_HomePhone(String value) {
			this.setInput("HomePhone", value);
		}


		/** 
		Set the value of the LastName input for this Choreo. 

		@param String - (optional, string) Corresponds to the last name field in Highrise.
		*/
		public void set_LastName(String value) {
			this.setInput("LastName", value);
		}


		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The Highrise account password. Use the value 'X' when specifying an API Key for the Username input.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}


		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (optional, string) Corresponds to the title field in Highrise.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}


		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A Highrise account username or API Key.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}


		/** 
		Set the value of the WorkPhone input for this Choreo. 

		@param String - (optional, string) Corresponds to the work phone field in Highrise.
		*/
		public void set_WorkPhone(String value) {
			this.setInput("WorkPhone", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreatePeople Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreatePeopleResultSet extends ResultSet {
		public CreatePeopleResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Highrise.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
