package com.temboo.Library.Stripe.Charges;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RefundCharge

Issues a refund of an existing credit card charge.
*/
public class RefundCharge extends Choreography {

	/**
	Create a new instance of the RefundCharge Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RefundCharge(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Charges/RefundCharge"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RefundChargeInputSet
	*/
	public RefundChargeInputSet newInputSet() {
		return new RefundChargeInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RefundChargeResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RefundChargeResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RefundCharge
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RefundChargeInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the Amount input for this Choreo. 

		@param Integer - (optional, integer) The amount to refund to the customer in cents. When left empty, the entire charge is refunded.
		*/
		public void set_Amount(Integer value) {
			this.setInput("Amount", value);
		}

		/** 
		Set the value of the Amount input for this Choreo as a String. 

		@param String - (optional, integer) The amount to refund to the customer in cents. When left empty, the entire charge is refunded.
		*/
		public void set_Amount(String value) {
			this.setInput("Amount", value);	
		}
		/** 
		Set the value of the ChargeID input for this Choreo. 

		@param String - (required, string) The unique identifier of the charge to be refunded
		*/
		public void set_ChargeID(String value) {
			this.setInput("ChargeID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RefundCharge Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RefundChargeResultSet extends ResultSet {
		public RefundChargeResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
