package com.temboo.Library.Twilio.AvailablePhoneNumbers;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
TollFreeList

Returns a list of toll-free available phone numbers that match the specified filters.
*/
public class TollFreeList extends Choreography {

	/**
	Create a new instance of the TollFreeList Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public TollFreeList(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twilio/AvailablePhoneNumbers/TollFreeList"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return TollFreeListInputSet
	*/
	public TollFreeListInputSet newInputSet() {
		return new TollFreeListInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public TollFreeListResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new TollFreeListResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the TollFreeList
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class TollFreeListInputSet extends InputSet {
		/** 
		Set the value of the AccountSID input for this Choreo. 

		@param String - (required, string) The AccountSID provided when you signed up for a Twilio account.
		*/
		public void set_AccountSID(String value) {
			this.setInput("AccountSID", value);
		}


		/** 
		Set the value of the AreaCode input for this Choreo. 

		@param Integer - (optional, integer) Find phone numbers in the specified area code. (US and Canada only).
		*/
		public void set_AreaCode(Integer value) {
			this.setInput("AreaCode", value);
		}

		/** 
		Set the value of the AreaCode input for this Choreo as a String. 

		@param String - (optional, integer) Find phone numbers in the specified area code. (US and Canada only).
		*/
		public void set_AreaCode(String value) {
			this.setInput("AreaCode", value);	
		}
		/** 
		Set the value of the AuthToken input for this Choreo. 

		@param String - (required, string) The authorization token provided when you signed up for a Twilio account.
		*/
		public void set_AuthToken(String value) {
			this.setInput("AuthToken", value);
		}


		/** 
		Set the value of the Contains input for this Choreo. 

		@param String - (optional, string) A pattern to match phone numbers on. Valid characters are '*' and [0-9a-zA-Z]. The '*' character will match any single digit.
		*/
		public void set_Contains(String value) {
			this.setInput("Contains", value);
		}


		/** 
		Set the value of the IsoCountryCode input for this Choreo. 

		@param String - (optional, string) The country code to search within. Defaults to US.
		*/
		public void set_IsoCountryCode(String value) {
			this.setInput("IsoCountryCode", value);
		}


		/** 
		Set the value of the Page input for this Choreo. 

		@param Integer - (optional, integer) The page of results to retrieve. Defaults to 0.
		*/
		public void set_Page(Integer value) {
			this.setInput("Page", value);
		}

		/** 
		Set the value of the Page input for this Choreo as a String. 

		@param String - (optional, integer) The page of results to retrieve. Defaults to 0.
		*/
		public void set_Page(String value) {
			this.setInput("Page", value);	
		}
		/** 
		Set the value of the PageSize input for this Choreo. 

		@param Integer - (optional, integer) The number of results per page.
		*/
		public void set_PageSize(Integer value) {
			this.setInput("PageSize", value);
		}

		/** 
		Set the value of the PageSize input for this Choreo as a String. 

		@param String - (optional, integer) The number of results per page.
		*/
		public void set_PageSize(String value) {
			this.setInput("PageSize", value);	
		}
		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the TollFreeList Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class TollFreeListResultSet extends ResultSet {
		public TollFreeListResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Twilio.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
